#### File structure in the data folder

```
.
├── MLmodels
│   ├── ANN
│   │   ├── def2tzvp.zip
│   │   └── lacvps.zip
│   ├── FT-ANN
│   │   ├── def2tzvp.zip
│   │   └── lacvps.zip
│   └── KRR
│       ├── def2tzvp.zip
│       └── lacvps.zip
├── README.md
├── datacsvfiles
│   ├── def2tzvp
│   │   ├── deltaSCFgap-def2tzvp-finaldata.csv
│   │   ├── n+1-electron-def2tzvp-rawdata.csv
│   │   ├── n-1-electron-def2tzvp-rawdata.csv
│   │   ├── n-electron-def2tzvp-rawdata.csv
│   │   ├── sse-def2tzvp-finaldata.csv
│   │   └── vertIP-def2tzvp-finaldata.csv
│   ├── lacvps
│   │   ├── deltaSCFgap-lacvps-finaldata.csv
│   │   ├── n+1-electron-lacvps-rawdata.csv
│   │   ├── n-1-electron-lacvps-rawdata.csv
│   │   ├── n-electron-lacvps-rawdata.csv
│   │   ├── sse-lacvps-finaldata.csv
│   │   └── vertIP-lacvps-finaldata.csv
│   └── unique-complexes
│       └── MD1-OHLDB-unique-complexes.csv
├── hyperparameters
│   ├── def2tzvp
│   │   ├── ann-hyperparams-lacvps.json
│   │   └── krr-hyperparams-def2tzvp.json
│   │   ├── ann-hyperparams-lacvps.csv
│   │   └── krr-hyperparams-def2tzvp.csv
│   └── lacvps
│       ├── ann-hyperparams-lacvps.json
│       └── krr-hyperparams-lacvps.json
│       ├── ann-hyperparams-lacvps.csv
│       └── krr-hyperparams-lacvps.csv
├── optimized-geometries
│   ├── unique-complexes
│   └── duplicates
└── selected-features
    ├── def2tzvp
    │   ├── def2tzvp-selected-features.csv
    │   └── def2tzvp-selected-features.json
    └── lacvps
        ├── lacvps-selected-features.csv
        └── lacvps-selected-features.json
```

***

#### datacsvfiles

##### Unique complexes

`datacsvfiles/unique-complexes/MD1-OHLDB-unique-complexes.csv` contains the detailed information of 2639 unique complexes from the MD1+OHLDB dataset. The information includes: `name`,  `metal`, `ox` (oxidation state), `ligstr` (ligands), the chemical formula of equatorial and axial ligands, `ligcharge` (total ligand charge), `charge`,` spin` (spin multiplicity), `ref` (restricted or unrestricted formalism), and `mol_graph_det` (the determinant of the connectivity matrix of the complex).

##### Raw data files for the calculations of N-1, N, N+1 electron systems

`datacsvfiles/<basis>/<num>-electron-<basis>-rawdata.csv`, where basis=lacvps/def2tzvp, num=n-1/n/n+1. In each csv file, besides the detailed information of each complex, we also have `energy (Ha)`, `alphaHOMO (Ha)`, `alphaLUMO (Ha)`, `betaHOMO (Ha`), and `betaLUMO (Ha)`, for all 23 functionals, with a format of `<functional>.<value>`.

##### Final data files for the properties (vertical IP, $\Delta$-SCF gap, spin-splitting energy)

`datacsvfiles/<basis>/<property>-<basis>-finaldata.csv`, where basis=lacvps/def2tzvp, property=sse/vertIP/deltaSCFgap. 

* For spin-splitting energy (SSE), besides the detailed information of each complex, we also have the  `LS-spin-multiplicity` and `HS-spin-multiplicity` for each pair of complexes, and `LS-energy (Ha)`,  `HS-energy (Ha)` and `sse (kcal/mol)` for each functional, with a format of `<functional>.<values>`. 
* For vertical IP (vert IP), besides the detailed information of each complex, we also have the spin multiplicity for n or (n-1)-electron system, and `n-electron-energy (Ha)` , `n-1-electron-energy (Ha)`, and `vert_ip (eV)` for each functional, with a format of `<functional>.<values>`. 
* For  $\Delta$-SCF gap (delta-SCF gap), besides the detailed information of each complex, we also have the spin multiplicity for n, (n-1), or (n+1)-electron system, and `n-electron-energy (Ha)` , `n-1-electron-energy (Ha)`, `n+1-electron-energy (Ha)`, and `delta_scf_gap (eV)` for each functional, with a format of `<functional>.<values>`. 

***

#### hyperparameters

`hyperparameters/<basis>/<model>-hyperparams-<basis>.json` gives the model hyperparameters, where basis=lacvps/def2tzvp, model=krr/ann. Each json file contains the hyperparameters for 69 models trained at 3 properties and 23 functionals and has a data structure: `{<property>: <functional>: {hyperparams}}`. Note that we don’t provide the hyperparameters of the fine-tuned ANN (FT-ANN) models because those models share the same hyperparameters with the B3LYP ANN model except that they have a reduced learning rate of 1e-5 (Details see the Supporting Information).

To load a json file in Python3, 

```python
import json
d = json.load(open("filename.json", "r"))
```

We also provide hyperparameters with human-readable csv files at: `hyperparameters/<basis>/<model>-hyperparams-<basis>.csv`, where basis=lacvps/def2tzvp, model=krr/ann. In each csv file, each row contains hyperparameters for a specific property and functional combination for a KRR or ANN model.

***

#### MLmodels

Note that the ML models were uploaded separaty to Zenodo: https://zenodo.org/record/5033476#.YNYv1i2ZPUJ, given their large sizes.

`MLmodels/<model>/<basis>.zip` gives all the ML models used in this work, where model=KRR/ANN/FT-ANN, basis=lacvps/def2tzvp. Each zip file contains 69 models trained at 23 functionals with 3 properties.

To load the model files in Python3,

* KRRmodels: 

  ```python
  import pickle
  model = pickle.load(open("filename.pkl", "rb"))
  ```

* ANN and FT-ANN models: 

  ```PYTHON
  import keras
  json_file = open('filename.json', 'r')
  loaded_model_json = json_file.read()
  json_file.close()
  loaded_model = keras.models.model_from_json(loaded_model_json)
  loaded_model.load_weights("filename.h5")
  ```

***

#### optimized-geometries

B3LYP/LACVP* equilibrium geometries for 2639 unique complexes (xyz file) and 189 duplicates (xyz file) in MD1 and OHLDB.

***

#### selected-features

We provide RFA-KRR selected features with human-readable csv files at: `selected-features/<basis>/<basis>-selected-features.csv`, where basis=lacvps/def2tzvp. In each csv file, each row contains features for a specific property at a specific functional.

We also provide RFA-KRR selected features in json format, which can be parsed more easily in Python: `selected-features/<basis>/<basis>-selected-features.json`, where, basis=lacvps/def2tzvp. Each json file contains 69 feature sets trained at 23 functionals with 3 properties and has the dictionary structures as: `{<prop>: {<functional>: [features as a list]}}`, where prop=vert_ip/delta_scf_gap/sse and functional=one of the 23 functionals we considered. 



